0.9.9 API documentation: vector_int4.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

vector_int4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_vec4.hpp"
6
7 namespace glm
8 {
11
15 typedef vec<4, int, defaultp> ivec4;
16
18 }//namespace glm
glm::ivec4
vec< 4, int, defaultp > ivec4
4 components vector of signed integer numbers.
Definition: vector_int4.hpp:15
glm
Definition: common.hpp:20